Pincer Integration
------------------

See ``pincer.py`` in the examples directory for an example on how to use the Voicebox object.

.. automodule:: songbird.pincer
   :members:
   :undoc-members:
   :show-inheritance:
